﻿using Syncfusion.Pdf;
using Syncfusion.Pdf.Parsing;
using Syncfusion.RDL.DOM;
using Syncfusion.ReportWriter;
using Syncfusion.Windows.PdfViewer;
using System;
using System.Collections.Generic;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Media;

namespace ReportViewer
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += MainWindow_Loaded;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            viewer.ReportPath = this.GetFullPath("Product Line Sales.rdl");
            viewer.Print += PrintButtonClick;
            viewer.RefreshReport();
        }

        private void PrintButtonClick(object sender, System.ComponentModel.CancelEventArgs e)
        {
            e.Cancel = true;
            PrintDialog printDialog = new PrintDialog();

            if (printDialog.ShowDialog() == true)
            {
                Syncfusion.Windows.Reports.Viewer.ReportViewer reportViewer = sender as Syncfusion.Windows.Reports.Viewer.ReportViewer;
                ReportWriter reportWriter = new ReportWriter(reportViewer.ReportPath);
                var parameterList = reportViewer.GetParameters();

                if (parameterList != null)
                {
                    List<Syncfusion.Windows.Reports.ReportParameter> parameters = new List<Syncfusion.Windows.Reports.ReportParameter>();

                    foreach (var parameter in parameterList)
                    {
                        parameters.Add(new Syncfusion.Windows.Reports.ReportParameter()
                        {
                            Name = parameter.Name,
                            Values = parameter.Values as List<string>
                        });
                    }

                    reportWriter.SetParameters(parameters);
                }

                MemoryStream stream = new MemoryStream();
                reportWriter.Save(stream, WriterFormat.PDF);
                PdfViewerControl pdfViewer = new PdfViewerControl();
                pdfViewer.Load(stream);
                printDialog.PrintDocument(pdfViewer.PrintDocument.DocumentPaginator, "Printing Report...");
            }
        }

        private string GetFullPath(string report)
        {
            string templateDirectory = @"../../AppData";
            string dir = new DirectoryInfo(templateDirectory).FullName;
            return System.IO.Path.Combine(dir, report);
        }

    }
}
